@@ -53,7 +53,7 @@ class CodePipelineStack(Stack):
                     repository = f"{info.get('url')}@{info.get('branch')}"
                 shellstep['input'] = self.add_source(repository=repository, code_build_clone_output=code_build_clone_output, trigger_on_push=trigger_on_push)
             self.step = self.shellstep(**shellstep)
-            self.pipeline = self.codepipeline(step=self.step, **codepipeline)
+            self.pipeline = self.codepipeline(step=self.step, self_pipeline=self_pipeline, **codepipeline)
 
     def shellstep(self, **shellstep) -> pipelines.ShellStep:
         if not 'commands' in shellstep:
@@ -64,13 +64,13 @@ class CodePipelineStack(Stack):
             ]
         return pipelines.ShellStep("Synth", **shellstep)
 
-    def codepipeline(self, step: pipelines.ShellStep, **cpattr) -> pipelines.CodePipeline:
+    def codepipeline(self, step: pipelines.ShellStep, *, self_pipeline: bool=False, **cpattr) -> pipelines.CodePipeline:
         cpipe = pipelines.CodePipeline(
             self, "Pipeline",
             synth=step,
             **cpattr
         )
-        if self.__connections_ssm:
+        if self_pipeline and self.__connections_ssm:
             self.ssm_policies(cpipe)
         return cpipe
 
