@@ -1,20 +1,20 @@
 #!/usr/bin/env python3
 import click
 import json
-from aws_parsecf.functions import Functions
-# whatever...
-Functions.REF_PSEUDO_FUNCTIONS['AWS::Partition'] = lambda self: 'aws'
-def localImportValue(self, value):
-    stackfx = value.split('lambdasExportsOutputFnGetAtt')
-    fxarn = stackfx[1].split('Arn')
-    return fxarn[0]
+# from aws_parsecf.functions import Functions
+# # whatever...
+# Functions.REF_PSEUDO_FUNCTIONS['AWS::Partition'] = lambda self: 'aws'
+# def localImportValue(self, value):
+#     stackfx = value.split('lambdasExportsOutputFnGetAtt')
+#     fxarn = stackfx[1].split('Arn')
+#     return fxarn[0]
 
-Functions.stuffit = localImportValue
-Functions.MAP['Fn::ImportValue'] = 'stuffit'
-# OR stuff directly with all Fn::ImportValue
-#Function._import_value_cache = dict()
+# Functions.stuffit = localImportValue
+# Functions.MAP['Fn::ImportValue'] = 'stuffit'
+# # OR stuff directly with all Fn::ImportValue
+# #Function._import_value_cache = dict()
 
-import aws_parsecf
+# import aws_parsecf
 
 
 @click.argument('template', type=click.types.STRING, required=True, default='template.json')
@@ -37,7 +37,7 @@ def cli(template: str):
         #     if str(k).find("S3Bucket") >= 0:
         #         params[k] = "cdk.out/asset||" + params[k]
         # Parse CFN template
-        tpl = aws_parsecf.loads_json(json.dumps(tpl_raw), default_region='eu-west-1', parameters=params)
+        # tpl = aws_parsecf.loads_json(json.dumps(tpl_raw), default_region='eu-west-1', parameters=params)
 
     # Scan resources and print out StateMachine(s)
     for k, r in tpl['Resources'].items():
